@@ -1,4 +1,5 @@
 import logging
+import ujson
 from typing import Optional, Dict
 
 import asyncio
@@ -13,6 +14,9 @@ from binance_chain.exceptions import (
 )
 
 
+requests.models.json = ujson
+
+
 class BaseApiClient:
 
     API_VERSION = 'v1'
@@ -737,7 +741,8 @@ class AsyncHttpApiClient(BaseApiClient):
         loop = kwargs.get('loop', asyncio.get_event_loop())
         session = aiohttp.ClientSession(
             loop=loop,
-            headers=self._get_headers()
+            headers=self._get_headers(),
+            json_serialize=ujson.dumps
         )
         return session
 
